@@ -49,6 +49,7 @@
 #include <KIO/Global>
 
 #include "qdbusmenubar_p.h"
+#include "qxdgdesktopportalfiledialog_p.h"
 
 static const QByteArray s_x11AppMenuServiceNamePropertyName = QByteArrayLiteral("_KDE_NET_WM_APPMENU_SERVICE_NAME");
 static const QByteArray s_x11AppMenuObjectPathPropertyName = QByteArrayLiteral("_KDE_NET_WM_APPMENU_OBJECT_PATH");
@@ -321,6 +322,9 @@ QPlatformDialogHelper *KdePlatformTheme::createPlatformDialogHelper(QPlatformThe
 {
     switch (type) {
     case QPlatformTheme::FileDialog:
+        if (useXdgDesktopPortal()) {
+            return new QXdgDesktopPortalFileDialog;
+        }
         return new KDEPlatformFileDialogHelper;
     case QPlatformTheme::FontDialog:
     case QPlatformTheme::ColorDialog:
@@ -390,3 +394,9 @@ void KdePlatformTheme::setQtQuickControlsTheme()
     }
     QQuickStyle::setStyle(QLatin1String("org.kde.desktop"));
 }
+
+bool KdePlatformTheme::useXdgDesktopPortal()
+{
+    static bool usePortal = qEnvironmentVariableIntValue("PLASMA_INTEGRATION_USE_PORTAL") == 1;
+    return usePortal;
+}
